@@ -49,6 +49,7 @@ class FastAvroDecoder:
     def decode(self, record):
 
         with primed_avro.util.ContextStringIO(record) as buf:
+
             magic, schema_id = struct.unpack(">bI", buf.read(5))
             if magic != MAGIC_BYTE:
                 raise SerializerError("record does not start with magic byte")
@@ -56,7 +57,7 @@ class FastAvroDecoder:
             schema = self._schema_registry.get_by_id(schema_id).schema
 
             return self._decoder(buf, schema)
-    
+
     def decode_with_meta(self, record):
 
         with primed_avro.util.ContextStringIO(record) as buf:
@@ -64,9 +65,9 @@ class FastAvroDecoder:
             if magic != MAGIC_BYTE:
                 raise SerializerError("record does not start with magic byte")
 
-            schema = self._schema_registry.get_by_id(schema_id).schema
+            schema = self._schema_registry.get_by_id(schema_id)
 
-            return self._decoder(buf, schema), schema, magic
+            return self._decoder(buf, schema.schema), schema, magic
 
 
 class Decoder:
